@@ -12,15 +12,16 @@ use Moose 2.1005;
 use MooseX::Singleton;    # ->instance becomes available
 use MediaCloud::JobManager::Job;
 use MediaCloud::JobManager::Broker;
+use MediaCloud::JobManager::Broker::Null;
 use MediaCloud::JobManager::Broker::RabbitMQ;
 
 # Instance of specific job broker
 has 'broker' => (
     is      => 'rw',
     isa     => 'MediaCloud::JobManager::Broker',
-    default => sub { return MediaCloud::JobManager::Broker::RabbitMQ->new(); },
+    default => sub { return MediaCloud::JobManager::Broker::Null->new(); },
 );
 
-no Moose;                 # gets rid of scaffolding
+no Moose;    # gets rid of scaffolding
 
 1;
